
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  TLI_hosts - psgconf action class to generate TLI hosts files
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::TLI_hosts;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;

	print $fh $self->{hostname} . "\t" . $self->{hostname} . "\n";

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::TLI_hosts - generate /etc/net/tic*/hosts files

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::TLI_hosts;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::TLI_hosts->new(
			'name'		=> '/etc/net/tic-whatever/hosts',
			'hostname'	=> '...',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::TLI_hosts> module provides a B<PSGConf>
action class for generating the Solaris F</etc/net/tic*/hosts> files.

The B<PSGConf::Action::GenerateFile::TLI_hosts> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generates the TLI hosts file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::TLI_hosts> class supports the following
attributes:

=over 4

=item I<hostname>

The FQDN of the host.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

