
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  dsm_opt.pm - psgconf action to generate TSM dsm.opt file
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::dsm_opt;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;

	print $fh "SErvername $self->{server}\n";
	print $fh "   domain ", join(' ', sort @{$self->{domain}}) . "\n";
	print $fh "   subdir yes\n\n";

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::dsm_opt - generate TSM dsm.opt file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::dsm_opt;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::dsm_opt->new(
			'name'		=> '/opt/tivoli/tsm/client/ba/bin/dsm.opt',
			'server'	=> '...',
			'domain'	=> [ ... ],
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::dsm_opt> module provides a B<PSGConf>
action class for generating the Tivoli Storage Manager (TSM) F<dsm.opt>
file.

The B<PSGConf::Action::GenerateFile::dsm_opt> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Creates the F<dsm.opt> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::dsm_opt> class supports the following
attributes:

=over 4

=item I<server>

The name of the server definition in F<dsm.sys>.

=item I<domain>

A reference to an array containing the directories to be backed up.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


