
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  dsm_sys.pm - psgconf action to generate TSM dsm.sys file
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::dsm_sys;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate() method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($server, $href, $opt);

	foreach $server (sort keys %{$self->{servers}})
	{
		$href = $self->{servers}->{$server};

		print $fh <<EOF;
SErvername $server
   COMMmethod         TCPip
   TCPPort            $href->{port}
   TCPServeraddress   $href->{server}
EOF

		foreach $opt (sort keys %{$href->{opts}})
		{
			if (ref($href->{opts}->{$opt}) eq 'ARRAY')
			{
				map {
					printf $fh "   %-18s %s\n", $opt, $_;
				} sort @{$href->{opts}->{$opt}};
				next;
			}
			printf $fh "   %-18s %s\n", $opt, $href->{opts}->{$opt};
		}

		print $fh "\n";
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::dsm_sys - generate TSM dsm.sys file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::dsm_sys;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::dsm_sys->new(
			'name'		=> '/opt/tivoli/tsm/client/ba/bin/dsm.sys',
			'servers'	=> {
					'servername' => {
							'server' => '...',
							'port' => 1500,
							'opts' => { ...  }
						},
					...
					},
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::dsm_sys> module provides a B<PSGConf>
action class for generating the TSM F<dsm.sys> file.

The B<PSGConf::Action::GenerateFile::dsm_sys> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Writes the value of the I<content> attribute to the output file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::dsm_sys> class supports the following
attributes:

=over 4

=item I<servers>

A hash mapping a TSM server label to a definition for that server.
The definition itself is a hash containing the keys I<server>, whose
value is the FQDN of the TSM server; I<port>, whose value is the TCP
port on which to contact the server; and I<opts>, whose value is a
reference to a hash containing options to be added to the stanza for
that server.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


