
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Action::GenerateFile::etc_rpc - action for /etc/rpc
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::etc_rpc;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($entry, $index);

	foreach $entry (@{$self->{entries}})
	{
		### print the RPC name
		print $fh $entry->[0];

		### print the RPC prgram number
		print $fh "\t$entry->[1]";

		### print the program names
		print $fh "\t$entry->[2]"
			if ( exists $entry->[2] );

		### add trailing newline
		print $fh "\n";
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::etc_rpc - generate /etc/rpc file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::etc_rpc;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::etc_rpc->new(
			'name'		=> '/etc/rpc',
			'entries'	=> [
				[ ... ],
				...
			],
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::etc_rpc> module provides a
B<PSGConf> action class for generating the RPC program file F<rpc>.

The B<PSGConf::Action::GenerateFile::etc_rpc> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generates the F<rpc> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::etc_rpc> class supports the following
attributes:

=over 4

=item I<entries>

An array containing the ordered list of entries to be written to the
file.  Each entry is a table with 3 elements, port name, port number and
a list of programs.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

