
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  etc_security_passwd.pm - psgconf action to generate /etc/security/passwd
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::etc_security_passwd;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate() method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($entry, $sort_func);

	$sort_func = $self->{sort_func};

	print $fh "\n";

	foreach $entry (sort $sort_func values %{$self->{user_info}})
	{
		print $fh "$entry->{name}:\n";
		print $fh "\tpassword = ";
		print $fh (defined($entry->{passwd})
			   ? $entry->{passwd}
			   : '*************');
		print $fh "\n\n";
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::etc_security_passwd - generate AIX /etc/security/passwd file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::etc_security_passwd;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::etc_security_passwd->new(
			'name'		=> '/etc/security/passwd',
			'user_info'	=> {
				'user'	=> {
					'name' => 'user',
					'passwd' => '...',
					...
				},
				...
			},
			'sort_func'	=> \&_sort_func,
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::etc_security_passwd> module provides
a B<PSGConf> action class for generating the AIX F</etc/security/passwd>
file.

The B<PSGConf::Action::GenerateFile::etc_security_passwd> class is derived
from the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the content for the F</etc/security/passwd> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::etc_security_passwd> class supports
the following attributes:

=over 4

=item I<user_info>

A hash mapping user names to a hash containing the fields for that user.
The hash for each user should contain the fields I<name>, which is set
to the name of the user, and I<passwd>, which is set to the encrypted
password for that user.  It may also contain a field called I<uid>,
which contains the numeric uid of the user; if present, this field will
be used to sort the entries in the file.  Any other fields are ignored.

=item I<sort_func>

A reference to a subroutine that will be used to sort the entries in
I<user_info>.

=back

=head1 BUGS

It might be useful to encode the I<lastupdate> and I<flags> fields for
each user.

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


