
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  etc_user_attr.pm - psgconf action to generate /etc/user_attr
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::etc_user_attr;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate() method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($entry);

	foreach $entry (sort keys %{$self->{user_info}})
	{
		if ( exists $self->{user_info}->{$entry}
			&& exists $self->{user_info}->{$entry}->{attributes} )
		{
			print $fh $self->{user_info}->{$entry}->{name} . ':';
			print $fh $self->{user_info}->{$entry}->{attributes}->{qualifier} . ':';
			print $fh $self->{user_info}->{$entry}->{attributes}->{res1} . ':';
			print $fh $self->{user_info}->{$entry}->{attributes}->{res2} . ':';
			print $fh $self->{user_info}->{$entry}->{attributes}->{attr};
			print $fh "\n";
		}
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::etc_user_attr - generate /etc/user_attr file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::etc_user_attr;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::etc_user_attr->new(
			'name'		=> '/etc/user_attr',
			'user_info'	=> {
				'username'	=> { ...  },
				...
			},
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::etc_user_attr> module provides a B<PSGConf>
action class for generating the F</etc/user_attr> file.

The B<PSGConf::Action::GenerateFile::etc_user_attr> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generates the F</etc/user_attr> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::etc_user_attr> class supports the following
attributes:

=over 4

=item I<user_info>

A hash mapping user names to a hash containing the fields for that user.
The hash for each user should contain the fields I<name>, which is set
to the name of the user; I<attributes>, which is an anomyous hash with
the following keys, I<qualifier>, I<res1>, I<res2>, I<attr>.  Currently
only the I<attr> tag is used on Solaris.

=back

=head1 AUTHOR

C<CE<lt>user_attr(4)E<gt>>

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


