
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Action::GenerateFile::hosts_allow - action for /etc/hosts.allow
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::hosts_allow;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($entry, $index);

	foreach $entry (@{$self->{entries}})
	{
		### print daemon list
		print $fh "\n$entry->[0] :";

		### print a unique sorted host list
		my (%hosts);
		map { $hosts{$_} = undef; } split (/\s+/, $entry->[1]);

		print $fh " \\\n\t"
			  . join(" \\\n\t", (sort keys %hosts));

		### add the remaining options
		for ($index = 2; $index < scalar(@$entry); $index++)
		{
			print $fh " \\\n\t: $entry->[$index]";
		}

		### add trailing newline
		print $fh "\n";
	}

	print $fh "\n";

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::hosts_allow - generate /etc/hosts.allow file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::hosts_allow;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::hosts_allow->new(
			'name'		=> '/etc/hosts.allow',
			'entries'	=> [
				[ ... ],
				...
			],
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::hosts_allow> module provides a
B<PSGConf> action class for generating the TCP wrappers F<hosts.allow>
file.

The B<PSGConf::Action::GenerateFile::hosts_allow> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generates the F<hosts.allow> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::hosts_allow> class supports the following
attributes:

=over 4

=item I<entries>

An array containing the ordered list of entries to be written to the
file.  Each entry is a reference to a list containing the daemons,
hosts, and options for that entry.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

