
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  sshd_config.pm - psgconf action to generate sshd_config files
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::ld_so_config;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate() method
###############################################################################

sub generate
{
  my ($self, $fh, $psgconf) = @_;
  my ($lib);

  foreach $lib (split(/:/, $self->{name} . '_library_path_list'))
  {
    print $fh $lib . "\n";
  }
  
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::ld_so_config - generate ld.so.conf config file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::ld_so_config;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::ld_so_config->new(
			'name'		=> '/etc/ld.so.conf',
			'library_path'	=> [ ... ],
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::ld_so_config> module provides a
B<PSGConf> action class for generating the linker F<ld_so_conf> file.

The B<PSGConf::Action::GenerateFile::ld_so_config> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the F<ld.so.conf> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::sshd_config> class supports the following
attributes:

=over 4

=item I<library_path>

A colon-separated list of directories for the loader to use

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

L<ld.so.conf>

=cut

