
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Action::GenerateFile::ntp_conf - action to generate ntp.conf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::ntp_conf;

use strict;

use PSGConf::Action::GenerateFile;
use PSGConf::Util;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my (@addrs, $server);

	map {
		print $fh "server $_";
		print $fh " minpoll " . $self->{minpoll}
			if ( $self->{minpoll} );
		print $fh " maxpoll " . $self->{maxpoll}
			if ( $self->{maxpoll} );
		print $fh "\n";
	} @{$self->{servers}};

	###
	### Fix the error messages "server returns a permission denied error"
	### when using xntpd (by now using the noserv option).
	###
	print $fh "restrict 127.0.0.1 noserve\n";

	print $fh "restrict 0.0.0.0 mask 0.0.0.0 ignore\n";
	foreach $server ( @{$self->{servers}} ) {
		@addrs = PSGConf::Util::get_addrs($psgconf, $server);
		map { print $fh "restrict $_\n"; } @addrs;
	}

	print $fh "driftfile " . $self->{driftfile} . "\n"
		if ( defined $self->{driftfile} );

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::ntp_conf - generate ntp.conf file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::ntp_conf;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::ntp_conf->new(
			'name'		=> '/etc/ntp.conf',
			'servers'	=> '...',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::ntp_conf> module provides a B<PSGConf>
action class for generating the F<ntp.conf> file.

The B<PSGConf::Action::GenerateFile::ntp_conf> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generates the F<ntp.conf> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::ntp_conf> class supports the following
attributes:

=over 4

=item I<servers>

The FQDN of the NTP servers.

=back

=head1 BUGS

This module should support more attributes to pass in various options,
rather than hard-coding so much information.

The module only sets up an NTP client, not a server.

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

