
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Action::GenerateFile::pam_file - action to generate /etc/pam.d/*
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::pam_file;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($entry);

	foreach $entry (@{$self->{pam_file}})
	{
		print $fh "$entry\n";
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::pam_file - generate /etc/pam.d/* files

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::pam_file;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::pam_file->new(
			'name'		=> '/etc/pam.d/service_name',
			'pam_file'	=> [ ... ],
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::pam_file> module provides a B<PSGConf>
action class for generating F</etc/pam.d/*> files.

The B<PSGConf::Action::GenerateFile::pam_file> class is derived from the
B<PSGConf::Action::GenerateFile> class, but it defines/overrides the
following methods:

=over 4

=item generate()

Generate F</etc/pam.d/service_name> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::pam_file> class supports the following
attributes:

=over 4

=item I<pam_file>

A reference to a list containing the entries to be written to the file.

=back

=head1 BUGS

The I<pam_file> attribute should be restructured to split up the fields
of the individual entries, rather than encoding them as a single
string.

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

