
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  sendmail_aliases.pm - psgconf action to generate sendmail aliases file
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::sendmail_aliases;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate() method
###############################################################################

my %_system_aliases = (
	postmaster	=> undef,
	'MAILER-DAEMON'	=> undef,
	nobody		=> undef,
	root		=> undef
);

sub generate
{
	my ($self, $fh, $psgconf) = @_;

	print $fh "\n### default system aliases\n";
	map {
		print $fh "$_:\t$self->{aliases}->{$_}\n"
			if (exists($self->{aliases}->{$_}));
	} (sort keys %_system_aliases);

	print $fh "\n### other aliases\n";
	map {
		print $fh "$_:\t$self->{aliases}->{$_}\n";
	} (sort grep { !exists($_system_aliases{$_}); }
						keys %{$self->{aliases}});

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::sendmail_aliases - generate sendmail aliases file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::sendmail_aliases;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::sendmail_aliases->new(
			'name'		=> '/etc/mail/aliases',
			'aliases'	=> { ... },
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::sendmail_aliases> module provides
a B<PSGConf> action class for generating the C<sendmail> F<aliases> file.

The B<PSGConf::Action::GenerateFile::sendmail_aliases> class is derived
from the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the F</etc/mail/aliases> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::sendmail_aliases> class supports the
following attributes:

=over 4

=item I<aliases>

A hash mapping aliases to their values.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


