
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  sendmail_trusted_users.pm - psgconf action for sendmail trusted-users file
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::sendmail_trusted_users;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate() method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;

	map { print $fh "$_\n"; } sort @{$self->{trusted_users}};

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::sendmail_trusted_users - generate trusted-users file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::sendmail_trusted_users;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::sendmail_trusted_users->new(
			'name'		=> '/etc/mail/trusted-users',
			'content'	=> '...',
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::sendmail_trusted_users> module
provides a B<PSGConf> action class for generating the C<sendmail>
F</etc/mail/trusted-users> file.

The B<PSGConf::Action::GenerateFile::sendmail_trusted_users> class
is derived from the B<PSGConf::Action::GenerateFile> class, but it
defines/overrides the following methods:

=over 4

=item generate()

Generates the F<trusted-users> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::sendmail_trusted_users> class supports
the following attributes:

=over 4

=item I<trusted_users>

A reference to a list of users.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


