
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  sshd_config.pm - psgconf action to generate sshd_config files
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::sshd_config;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate() method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($opt);

	$self->{ports} = []
		if (!defined($self->{ports}));
	foreach $opt (sort @{$self->{ports}})
	{
		print $fh "Port\t$opt\n";
	}

	$self->{listen_addrs} = {}
		if (!defined($self->{listen_addrs}));
	foreach $opt (sort keys %{$self->{listen_addrs}})
	{
		print $fh "ListenAddress\t$opt\n";
	}

	$self->{host_keys} = []
		if (!defined($self->{host_keys}));
	foreach $opt (sort @{$self->{host_keys}})
	{
		print $fh "HostKey\t$opt\n";
	}

	$self->{options} = {}
		if (!defined($self->{options}));
	foreach $opt (sort keys %{$self->{options}})
	{
		print $fh "$opt\t$self->{options}->{$opt}\n";
	}

	$self->{subsystems} = {}
		if (!defined($self->{subsystems}));
	foreach $opt (sort keys %{$self->{subsystems}})
	{
		print $fh "Subsystem\t$opt\t$self->{subsystems}->{$opt}\n";
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::sshd_config - generate sshd_config file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::sshd_config;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::sshd_config->new(
			'name'		=> '/etc/sshd_config',
			'ports'		=> [ ... ],
			'listen_addrs'	=> { ... },
			'host_keys'	=> [ ... ],
			'options'	=> { ... },
			'subsystems'	=> { ... },
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::sshd_config> module provides a
B<PSGConf> action class for generating the OpenSSH F<sshd_config> file.

The B<PSGConf::Action::GenerateFile::sshd_config> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the F<sshd_config> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::sshd_config> class supports the following
attributes:

=over 4

=item I<ports>

A list of ports to listen on.

=item I<listen_addrs>

A hash whose keys are address/port combinations to listen on.

=item I<host_keys>

A list of absolute paths of host key files.

=item I<options>

A hash of option/value pairs.

=item I<subsystems>

A hash mapping subsystem name to associated command.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


