
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  tsm_inclexcl.pm - psgconf action to generate TSM include/exclude file
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::tsm_inclexcl;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($type, $outtype);

	### exclude directives
	foreach $type (sort keys %{$self->{exclude}})
	{
		$outtype = ($type ne '-' ? ".$type" : '');
		map { print $fh "exclude$outtype $_\n" }
			sort keys %{$self->{exclude}->{$type}};
	}

	### include directives
	foreach $type (sort keys %{$self->{include}})
	{
		$outtype = ($type ne '-' ? ".$type" : '');
		map { print $fh "include$outtype $_\n" }
			sort keys %{$self->{include}->{$type}};
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::tsm_inclexcl - generate TSM include/exclude file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::tsm_inclexcl;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::tsm_inclexcl->new(
			'name'		=> '/opt/tivoli/tsm/client/ba/bin/inex.list',
			'exclude'	=> { ... },
			'include'	=> { ... },
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::tsm_inclexcl> module provides a
B<PSGConf> action class for generating a TSM include/exclude file.

The B<PSGConf::Action::GenerateFile::tsm_inclexcl> class is derived from
the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generate the include/exclude file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::tsm_inclexcl> class supports the
following attributes:

=over 4

=item I<exclude>

A hash mapping the exclude type to a hash whose keys are the paths to be
excluded.  An exclude type of C<-> means no type.

=item I<include>

A hash mapping the include type to a hash whose keys are the paths to be
included.  An include type of C<-> means no type.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut


