
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  workers_properties.pm - psgconf action class for mod_jk workers.properties
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::GenerateFile::workers_properties;

use strict;

use PSGConf::Action::GenerateFile;

our @ISA = qw(PSGConf::Action::GenerateFile);


###############################################################################
###  generate method
###############################################################################

sub generate
{
	my ($self, $fh, $psgconf) = @_;
	my ($worker);

	print $fh 'worker.list=';
	print $fh join(',', sort keys %{$self->{workers}});
	print $fh "\n";

	foreach $worker (sort keys %{$self->{workers}})
	{
		print $fh "worker.$worker.type="
			  . (defined($self->{workers}->{$worker}->[2])
			     ? $self->{workers}->{$worker}->[2]
			     : 'ajp13')
			  . "\n";
		print $fh "worker.$worker.port="
			  . $self->{workers}->{$worker}->[0]
			  . "\n";
		print $fh "worker.$worker.host="
			  . (defined($self->{workers}->{$worker}->[1])
			     ? $self->{workers}->{$worker}->[1]
			     : 'localhost')
			  . "\n";
	}

	return 1;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::GenerateFile::workers_properties - generate workers.properties file

=head1 SYNOPSIS

  use PSGConf::Action::GenerateFile::workers_properties;

  $psgconf->register_actions(
		PSGConf::Action::GenerateFile::workers_properties->new(
			'name'		=> '/usr/local/etc/apache/jk/workers.properties',
			'www_jk_workers' => { ... },
			...
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::GenerateFile::workers_properties> module provides a
B<PSGConf> action class for generating the C<mod_jk> F<workers.properties>
file.

The B<PSGConf::Action::GenerateFile::workers_properties> class is derived
from the B<PSGConf::Action::GenerateFile> class, but it defines/overrides
the following methods:

=over 4

=item generate()

Generates the F<workers.properties> file.

=back

In addition to the attributes supported by
the B<PSGConf::Action::GenerateFile> class, the
B<PSGConf::Action::GenerateFile::workers_properties> class supports the
following attributes:

=over 4

=item I<www_jk_workers>

A hash mapping the name of each worker to a list of parameters for
that worker.  The parameters are, in order, the port, host, and type of
the worker.  The port must be specified.  The host is optional and
defaults to C<localhost>.  The type is optional and defaults to
C<ajp13>.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Action::GenerateFile>

=cut

