
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Action::svcs::import - setting svcs property action type for psgconf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Action::svcs::import;

use strict;

use PSGConf::Action;

use PSGConf::Util;

our @ISA = qw(PSGConf::Action);


###############################################################################
###  check method
###############################################################################
sub check
{
     my ($self, $psgconf) = @_;
     my ($cmd, $value, $output);

	$value = $self->{value};

	$cmd = '/usr/sbin/svccfg';

	$cmd .= ' -s ' . $self->{FMRI}
		if ( $self->{FMRI} );

	$cmd .= ' list > /dev/null 2>&1';
          
	$self->{changed} = &PSGConf::Util::RunCommand(${cmd}, 1);

	return ($self->{changed});
}


###############################################################################
###  diff method
###############################################################################

sub diff
{
	my ($self) = @_;
	my ($cmd);

     $cmd = '/usr/sbin/svccfg import ' . $self->{manifest};

	print "###############################################################################\n";
	print "### DIFF FOR $self->{name}\n";
	print "###############################################################################\n";
	print "+ import: ${cmd}\n";
	print "\n";
}


###############################################################################
###  do() method
###############################################################################

sub do
{
	my ($self) = @_;
	my ($cmd, $val, $res);

	if ( -f $self->{manifest} ) {
     	$cmd = '/usr/sbin/svccfg import ' . $self->{manifest};

		return (!&PSGConf::Util::RunCommand(${cmd}));
	} else {
		warn "\t!!! Could not find manifest (" . $self->{manifest} . ")\n";
		return 0;
	}
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Action::svcs::import - setting svcs property action type for psgconf

=head1 SYNOPSIS

  use PSGConf::Action::svcs::import;

  $psgconf->register_actions(
		PSGConf::Action::svcs::import->new(
			'name'		=> 'message about property being set',
			'FMRI'		=> 'The FMRI to work on ...',
			'manifest'	=> 'The manifest file to import...',
		),
		...
	);

=head1 DESCRIPTION

The B<PSGConf::Action::svcs::import> module provides a B<PSGConf> action
class for importing new definitions into the System Management Facility .

The B<PSGConf::Action::svcs::import> class is derived from the
B<PSGConf::Action> class, but it defines/overrides the
following methods:

=over 4

=item check()

Checks to see if the I<FMRI> is in the SMF repository.  If not, then
it sets the changed flag so that later on, the C<svccfg import> will
get run.

=item diff()

Prints a message indicating that C<svccfg import> will be executed.

=item do()

Actually executes the C<svccfg import> command.

=back

In addition to the attributes supported by the B<PSGConf::Action>
class, the B<PSGConf::Action::svcs::import> class supports the following
attributes:

=over 4

=item I<FMRI>

The Fault Management Resource Identifier to validate is in the repository.

=item I<manifest>

The manifest that defines the I<FMRI>.

Note that the I<name> attribute will only be used to print the
"checking" message when the check() method is called.

=back

=head1 SEE ALSO

C<CE<lt>smf(5)E<gt>>

C<CE<lt>svccfg(1m)E<gt>>

L<perl>

L<PSGConf>

L<PSGConf::Action>

=cut

