
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Data::Boolean - boolean data type for PSGConf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::Data::Boolean;

use strict;

use PSGConf::Data::Enum;

our @ISA = qw(PSGConf::Data::Enum);


###############################################################################
###  constructor
###############################################################################

sub new
{
     my ($class, %opts) = @_;

	return PSGConf::Data::Enum->new(
			default => 'yes',
			values =>
				[ [ 'no', 'off', 'false', 'f', 0 ],
				  [ 'yes', 'on', 'true', 't', 1 ] ],
			%opts
		);
}

###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Data::Boolean - boolean data type class for PSGConf

=head1 SYNOPSIS

  use PSGConf::Data::Boolean;

  $psgconf->register_data(
		'boolobj'	=> PSGConf::Data::Boolean->new()
	);

=head1 DESCRIPTION

The B<PSGConf::Data::Boolean> module provides a class that
represents a boolean value in an object so that it can be used with
B<PSGConf>.  Its methods can be used to manipulate the
encapsulated boolean value from the B<PSGConf> data store(s).

The B<PSGConf::Data::Boolean> class is derived from the
B<<PSGConf::Data::Enum> class, but it defines/overrides the
following method:

=over 4

=item new()

Sets the subset of the object's values to the following enumerated
list: "yes", "no", "on", "off", "true", "false", "t", "f", 1, or 0.

=back

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<PSGConf::Data::Enum>

=cut

