
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::DataStore::Storable - binary config file data store for psgconf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


package PSGConf::DataStore::Storable;

use PSGConf::DataStore;
use Storable;

use strict;

our @ISA = qw(PSGConf::DataStore);

###############################################################################
###  read config
###############################################################################

sub read_config
{
	my ($self, $psgconf) = @_;
	my ($file);

	###
	### This looks backwards, but using $psgconf first is so command
	### line options for a config file get processed before a default
	### from the class creation.
	###
	$file = defined($psgconf->{'config_file'})
		 		? $psgconf->{'config_file'}
		 		: $self->{'config_file'};

	$psgconf->{'data'} = retrieve($file);
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::DataStore::Storable - binary config file data store for psgconf

=head1 SYNOPSIS

In F<psgconf_modules>:

  DataStore PSGConf::DataStore::Storable config_file=/etc/psg.store

=head1 DESCRIPTION

The B<PSGConf::DataStore::Storable> module provides a data store
implementation that reads configuration information from a local config
file (typically F</etc/psg.store>).  It supports the following methods:

=over 4

=item new()

The constructor.  Its arguments are a reference to the B<PSGConf>
object and an optional list of attribute settings in the form
"attribute=value".  The following attributes are supported:

=over 4

=item I<config_file>

The absolute path to the default config file location.  This value is
overriden by the I<config_file> attribute of the B<PSGConf> object.

=back

=item read_config()

Reads the config file.  Its argument is a reference to the B<PSGConf>
object.

=back

The config file parser is implemented using B<Storable>.
See L<Storable> for details on the config file format.

=head1 SEE ALSO

L<perl>

L<PSGConf>

L<psgconf-intro>

L<Storable>

=cut

