
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Import::pkg_default_versions - psgconf-import module to parse input
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Import::pkg_default_versions;

use strict;

BEGIN {
	use Exporter ();
	our (@ISA, @EXPORT);
	@ISA = qw(Exporter);
	@EXPORT = qw(&init &parse);
}

sub init {
	my ($psgconf) = @_;
	my ($self, $control, $ctrl);

	$psgconf->access_data_stores();

	### Find the Packages Control module so we can figure out 
	### what packging system we are using
	foreach $ctrl ( @{$psgconf->{controls}} ) {
		if ( $ctrl =~ m/PSGConf::Control::Packages/o ) {
			$control = $ctrl;
			last;
		}
	}

	### Now create the Action::PackageManager module, so we can
	### use the Parse() routine.
	$self = $control->{pkg_action}->new (
		name				=> $control->{pkg_action} . ' Packages',
		quiet			=> 1,
		seperator			=> $psgconf->data_obj('pkg_seperator')->get(),
		sep_regex			=> $psgconf->data_obj('pkg_seperator_regex')->get(),
		install_list		=> $psgconf->data_obj('pkg_install_list')->get(),
		warn_unselected	=> $psgconf->data_obj('pkg_warn_unselected')->get(),
		remove_unselected	=> $psgconf->data_obj('pkg_remove_unselected')->get(),
		number_of_versions	=> $psgconf->data_obj('pkg_number_of_versions')->get()
	) || die "Can not instantiate $control->{pkg_action} module\n";

	return $self;
}

sub parse {
	my ($self, $line) = @_;
	my (@res);

	($res[0]) = $self->Parse($line);

	###
	### If we do not have a package name, return nothing...
	###
	return ()
		if ( ! length ($res[0]) );

	$res[1] = $line; $res[1] =~ s/^\Q${res[0]}\E$self->{seperator}->[0]//;

	###
	### If the package and version match, we also have garbage.
	###
	return ()
		if ( $res[0] eq $res[1] );

	return @res;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Import::pkg_default_versions - psgconf-import module to parse input

=head1 SYNOPSIS

  use PSGConf::Import::pkg_default_versions;

=head1 DESCRIPTION

The B<PSGConf::Import::pkg_default_versions> module provides a
class which defines how psgconf-import will parse the output
from commands like C<up2date> to write out Config::Objective
formatted directives to use in psgconf config files.

=over 4

=item init()

Initializes psgconf to get the defined
C<PSGConf::Action::PackageManager::XX> for this system.  This is
to use the method C<Parse()> for use with the existing package
management system.

=item parse()

Reads the standard input and returns a C<PSGConf::Data::List>
object for each line, where the first element is the package
name and the second is the complete version number.

=back

=head1 SEE ALSO

L<perl>

L<Config::Objective>

=cut

