
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  PSGConf::Import::ports - psgconf-import module to parse input
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

package PSGConf::Import::ports;

use strict;

BEGIN {
	use Exporter ();
	our (@ISA, @EXPORT);
	@ISA = qw(Exporter);
	@EXPORT = qw(&init &parse);
}

sub init {
	my ($psgconf) = @_;
	my ($self);

	return $self;
}

sub parse {
	my ($self, $line) = @_;
	my ($i, @a, @res);

	### Remove all comments...
	$line =~ s/#.*$//;

	@a = split /[\s\t]+/, $line;

	if ( scalar @a > 1 ) {

		### Quote the port name if we have special characters
		$res[0] = shift @a;
		$res[0] = q(") . $res[0] . q(") if ( $res[0] =~ m/[-\*\+\.\\]+/ );

		### Quote the port number because of the '/' in it.
		$res[1] = shift @a;
		$res[1] = q(") . $res[1] . q(");

		### Quote the aliases if there are more than 1 or a hyphen
		if ( scalar @a ) {
			$res[2] = join (' ', @a);
			$res[2] = q(") . $res[2] . q(")
				if ( scalar @a > 1 || $res[2] =~ m/[-\*\+\.\\]+/ );
		}
	}

	return @res;
}


###############################################################################
###  documentation
###############################################################################

1;

__END__

=head1 NAME

PSGConf::Import::ports - psgconf-import module to parse input

=head1 SYNOPSIS

  use PSGConf::Import::ports;

=head1 DESCRIPTION

The B<PSGConf::Import::Data::ports> module provides a class which
defines how this data object should be imported into PSGConf itself.

=head1 SEE ALSO

L<perl>

L<Config::Objective>

=cut

