
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  04-data.t - test script for Data Modules.
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

use Test;
use warnings;

BEGIN { plan tests => 60; };

################################################################################

use PSGConf::Data::Enum;
$enum = PSGConf::Data::Enum->new(
	default	=> 'ignore',
	values	=> [ [ 'enable' ],
				[ 'disable' ],
				[ 'ignore' ] ]
);
ok ($enum->get(), undef, "Failed Data::Enum->new()\n");

$enum->set();
ok ($enum->get(), 2, "Data::Enum error in set(default)\n");
ok ($enum->equals('ignore'), 1, "Data::Enum error in equals()\n");

$enum->set('enable');
ok ($enum->get(), 0, "Data::Enum error in set(enable)\n");
ok (! $enum->equals('ignore'), 1, "Data::Enum error in equals()\n");
ok ($enum->exists(), 1, "Data::Enum error in exists()\n");
$enum->unset();
ok ($enum->get(), undef, "Data::Enum error in unset()\n");

################################################################################
use PSGConf::Data::Boolean;

$bool = PSGConf::Data::Boolean->new();

ok ($bool->get(), undef, "Failed Data::Boolean->new()\n");

$bool->set();
ok ($bool->get(), 1, "Data::Boolean error in set(default)\n");
ok ($bool->equals('false'), "", "Data::Boolean error in equals()\n");
ok ($bool->exists(), 1, "Data::Boolean error in exists\n");
$bool->unset();
ok ($bool->get(), undef, "Data::Boolean error in unset()\n");

################################################################################
use PSGConf::Data::Integer;

$int = PSGConf::Data::Integer->new();
ok ($int->get(), undef, "Failed Data::Integer->new()\n");

$int->set(0xa);
ok ($int->get(), 10, "Data::Integer cannot handle hex values\n");

$int->set(010);
ok ($int->get(), 8, "Data::Integer cannot handle octal values\n");

ok ($int->exists(), 1, "Data::Integer error in exists\n");

$int->add(10);
ok ($int->get(), 18, "Data::Integer error in addition\n");

$int->sub(0x2);
ok ($int->get(), 16, "Data::Integer error in subtraction\n");

$int->div(010);
ok ($int->get(), 2, "Data::Integer error in division\n");

$int->mult(0xC);
ok ($int->get(), 24, "Data::Integer error in multiplication\n");

$int->incr();
ok ($int->get(), 25, "Data::Integer error in increment\n");

$int->decr();
ok ($int->get(), 24, "Data::Integer error in decrement\n");

ok ($int->eq(24), 1, "Data::Integer error in eq()\n");
ok ($int->eq(25), "", "Data::Integer error in eq()\n");
ok ($int->ne(24), "", "Data::Integer error in eq()\n");
ok ($int->ne(25), 1, "Data::Integer error in eq()\n");
ok ($int->lt(20), "", "Data::Integer error in lt()\n");
ok ($int->le(24), 1, "Data::Integer error in le()\n");
ok ($int->gt(20), 1, "Data::Integer error in gt()\n");
ok ($int->ge(24), 1, "Data::Integer error in ge()\n");
$int->unset();
ok ($int->get(), undef, "Data::Integer error in unset()\n");

################################################################################
use PSGConf::Data::String;

$string = PSGConf::Data::String->new();
ok ($string->get(), undef, "Failed Data::String->new()\n");

$string->set('foo');
ok ($string->get(), 'foo', "Data::String error in set()\n");

$string->append(' bar');
ok ($string->get(), 'foo bar', "Data::String error in append()\n");

$string->prepend('baz ');
ok ($string->get(), 'baz foo bar', "Data::String error in prepend()\n");

$string->gsub('ba', 'Ba');
ok ($string->get(), 'Baz foo Bar', "Data::String error in gsub()\n");

ok ($string->match('[bB]a'), 1, "Data::String error in match()\n");
$string->unset();
ok ($string->get(), undef, "Data::String error in unset()\n");

################################################################################
use PSGConf::Data::List;

$list = PSGConf::Data::List->new();

ok ($list->count(), 0, "Data::List error in count(0)\n");
ok ($list->add('a'), 1, "Data::List error in add()\n");
ok ($list->add_top('1'), 1, "Data::List error in add_top()\n");
ok ($list->count(), 2, "Data::List error in count(2)\n");
ok ($list->find('a'), 'a', "Data::List error in find('a')\n");
ok ($list->delete('a'), 1, "Data::List error in delete()\n");
$list->set('z');
ok ($list->count(), 1, "Data::List error in set()\n");
$list->unset();
ok ($list->count(), 0, "Data::List error in count(0)\n");

################################################################################
use PSGConf::Data::Hash;

$hash = PSGConf::Data::Hash->new();
ok ($hash->count(), 0, "Data::Hash error in count(0)\n");

$hash->set( { 'name' => 'foo' } );
ok ($hash->count(), 1, "Data::Hash error in count(1)\n");

$hash->insert( { 'descr' => 'test case' } );
ok ($hash->count(), 2, "Data::Hash error in count(2)\n");

ok ($hash->find('name'), 'foo', "Data::Hash error in find()\n");
ok ($hash->find('foo'), undef, "Data::Hash error in find(undef)\n");
ok ($hash->delete('descr'), 1, "Data::Hash error in delete()\n");

$hash->unset();
ok ($hash->count(), 0, "Data::Hash error in count(0)\n");

################################################################################
use PSGConf::Data::Table;

$table = PSGConf::Data::Table->new();
ok ($table->count_row(), 0, "Data::Table error in count_row(0)\n");

$table->set( [[ 'sshd', 'localhost', 'allow' ]] );
$table->insert_row( { 0 => '\bsshd\b' }, [ 'ssh_root', 'my.host', 'allow' ] );
ok ($table->count_row(), 2, "Data::Table error in count_row(2)\n");
ok ($table->count_col(), 3, "Data::Table error in count_col()\n");
ok (defined $table->find_row({ 0 => '\bsshd\b'}), 1, "Data::Table error in find_row()\n");
$table->replace_row_cells({ 0 => '\bsshd\b'}, { 1 => 'localhost.new' });
ok ($table->count_row(), 2, "Data::Table error in count_row(2)\n");
$table->append_to_row_cells({ 0 => '\bssh_root\b'}, { 1 => 'localhost.new' });
ok ($table->count_row(), 2, "Data::Table error in count_row(2)\n");
$table->delete_row({ 0 => '\bssh_root\b'});
ok ($table->count_row(), 1, "Data::Table error in count_row(1)\n");
