
###
###  Copyright 2000-2007 University of Illinois Board of Trustees
###  All rights reserved. 
###
###  05-datastore.t - test script for DataStore Modules.
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###

use Test;
use File::Find;
use warnings;
use PSGConf;

### Find all the perl modules and add them to the list to use.
sub wanted {
	### Ignore CVS directories and VIM swap files.
	-d $_ && $_ eq 'CVS' && ($File::Find::prune = 1);
	-f $_ &&  $_ !~ /^\..*.swp$/ && push @found, $File::Find::name
}
File::Find::find({wanted => \&wanted}, 'lib/PSGConf/DataStore');

plan tests => scalar @found * 2;

%opts = (
	config_dir => 'config',
	modules_file => 't/psgconf_modules.test',
	rm_tmpfiles => 1
);
$ENV{'PSGCONF_TMPDIR'} = '.';

foreach $module ( @found ) {

	###
	### Massage the file name to convert it into perl use syntax
	###
	$module =~ s,^lib/,,;
	$module =~ s,/,::,g;
	$module =~ s/.pm$//;

	if ( $module =~ /::AppConfig$/ ) {
		$ext = 'ini';
	} elsif ( $module =~ /::Storable$/ ) {
		$ext = 'store';
	} elsif ( $module =~ /::ConfigFile$/ ) {
		$^W = 0;			# To shut up Parse::Token about redefinitons
		$ext = 'conf';
	} else {
		$ext = 'conf';
	}

	### Create a dummy psg.$ext file, if it does not exists
	if ( ! -f "etc/psg.${ext}" ) {
		open(FP, "> etc/psg.${ext}");
		close FP;
	}

	### Create the t/psgconf_modules.test file
	if ( open(FP, '> t/psgconf_modules.test' )) {
		printf FP "DataStore	$module	config_file=etc/psg.${ext}\n";
		close FP;
	} else {
		ok (0, 1, "Could not create t/psgconf_modules.test file\n");
	} 

	eval "use $module;";

	my ($psgconf) = PSGConf->new(%opts);
	my ($ds) = $module->new($psgconf, ( "config_file=etc/psg.${ext}" ));

	ok (defined $ds, 1, "$module->new failed\n");

	eval { $ds->read_config($psgconf); };

	ok ($?, 0, "$module->read_config failed\n");

	unlink ("etc/psg.${ext}")
		if ( ! -s "etc/psg.${ext}" );
}

unlink ('t/psgconf_modules.test')
	if ( -f 't/psgconf_modules.test' );
